@@ -1,7 +1,7 @@
 /*
  *      backendgvfs.c
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -551,7 +551,7 @@ static void mount_ready_cb(GFile *location, GAsyncResult *res, MountInfo *mi)
 	if (error != NULL)
 		g_error_free(error);
 
-	if (mi->dialog != NULL)
+	if (mi->dialog != NULL && GTK_IS_WIDGET(mi->dialog))
 		gtk_widget_destroy(mi->dialog);
 
 	g_free(uri);
