@@ -1,7 +1,7 @@
 /*
  *      bookmarkdialog.c
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include "settings.h"
 #include "bookmark.h"
+#include "settings.h"
 #include "backendgvfs.h"
 #include "window.h"
 #include "compat.h"
@@ -98,6 +98,18 @@ static void update_row_in_model(GigoloBookmarkDialog *dialog, GtkTreeIter *iter,
 			g_string_append(other_text, ", ");
 		g_string_append_printf(other_text, _("Share: %s"), tmp);
 	}
+	if (NZV(tmp = gigolo_bookmark_get_folder(bm)))
+	{
+		if (other_text->len > 0)
+			g_string_append(other_text, ", ");
+		g_string_append_printf(other_text, _("Folder: %s"), tmp);
+	}
+	if (NZV(tmp = gigolo_bookmark_get_path(bm)))
+	{
+		if (other_text->len > 0)
+			g_string_append(other_text, ", ");
+		g_string_append_printf(other_text, _("Path: %s"), tmp);
+	}
 
 	gtk_list_store_set(priv->store, iter,
 			COL_NAME, gigolo_bookmark_get_name(bm),
