@@ -1,7 +1,7 @@
 /*
  *      common.c
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -149,7 +149,7 @@ gboolean gigolo_is_desktop_xfce(void)
 }
 
 
-gboolean gigolo_message_dialog(gpointer *parent, gint type, const gchar *title,
+gboolean gigolo_message_dialog(gpointer parent, gint type, const gchar *title,
 							   const gchar *text, const gchar *secondary)
 {
 	gboolean ret = FALSE;
