@@ -1,7 +1,7 @@
 /*
  *      common.h
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -43,6 +43,9 @@ void debug(gchar const *format, ...) G_GNUC_PRINTF (1, 2);
 # define debug(...)
 #endif
 
+#define GIGOLO_BOOKMARK_NAME_NONE "none"
+
+
 void verbose(gchar const *format, ...) G_GNUC_PRINTF (1, 2);
 
 
@@ -58,7 +61,7 @@ void gigolo_show_uri(const gchar *uri);
 
 guint gigolo_get_default_port(const gchar *scheme);
 
-gboolean gigolo_message_dialog(gpointer *parent, gint type, const gchar *title,
+gboolean gigolo_message_dialog(gpointer parent, gint type, const gchar *title,
 							   const gchar *text, const gchar *secondary);
 
 const gchar *gigolo_get_application_icon_name(void);
