@@ -1,7 +1,7 @@
 /*
  *      main.c
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -68,7 +68,6 @@ gint main(gint argc, gchar** argv)
 {
 	GigoloSettings *settings;
 	GigoloSingleInstance *gis = NULL;
-	const gchar *vm_impl;
 	gchar *accel_filename;
 	GOptionContext *context;
 	GtkWidget *window;
@@ -89,7 +88,7 @@ gint main(gint argc, gchar** argv)
 	if (show_version)
 	{
 		g_print("%s %s\n\n", PACKAGE, VERSION);
-		g_print("%s\n", "Copyright (c) 2008-2009");
+		g_print("%s\n", "Copyright (c) 2008-2010");
 		g_print("\tEnrico Tröger <enrico@xfce.org>\n\n");
 		g_print("\n");
 
@@ -124,11 +123,6 @@ gint main(gint argc, gchar** argv)
 	accel_filename = g_build_filename(g_get_user_config_dir(), PACKAGE, "accels", NULL);
 	gtk_accel_map_load(accel_filename);
 
-	/* GVfs currently depends on gnome-mount for HAL-based GVolumeMonitor implementation,
-	 * when gnome-mount is not installed, we can use "unix" as GVolumeMonitor implementation. */
-	if ((vm_impl = gigolo_settings_get_vm_impl(settings)) != NULL)
-		g_setenv("GIO_USE_VOLUME_MONITOR", vm_impl, 0);
-
 	window = gigolo_window_new(settings);
 
 	if (gis != NULL)
