@@ -1,7 +1,7 @@
 /*
  *      main.h
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -20,13 +20,5 @@
 #ifndef __MAIN_H__
 #define __MAIN_H__
 
-#ifdef DEBUG
-void debug(gchar const *format, ...);
-#else
-# define debug(...)
-#endif
-
-void verbose(gchar const *format, ...);
-
 
 #endif /* __MAIN_H__ */
