@@ -1,7 +1,7 @@
 /*
  *      settings.c
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -27,10 +27,9 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "bookmark.h"
 #include "settings.h"
 #include "common.h"
-#include "bookmark.h"
-#include "main.h"
 
 
 typedef struct _GigoloSettingsPrivate			GigoloSettingsPrivate;
@@ -51,10 +50,12 @@ struct _GigoloSettingsPrivate
 	gint		toolbar_style;
 	gint		toolbar_orientation;
 	gint		view_mode;
+	gboolean	show_panel;
+	guint		last_panel_page;
+	gboolean	show_autoconnect_errors;
 
 	gchar		*file_manager;
 	gint		 autoconnect_interval;
-	gchar		*vm_impl; /* GVolumeMonitor implementation to use */
 	gint		*geometry; /* window size and position, field 4 is a flag for maximized state */
 
 	GigoloBookmarkList *bookmarks; /* array of known bookmarks */
@@ -69,7 +70,6 @@ static void gigolo_settings_finalize			(GObject* object);
 
 /* default values */
 #define DEFAULT_AUTOCONNECT_INTERVAL	60
-#define DEFAULT_VM_IMPL					"hal"
 
 enum
 {
@@ -84,7 +84,10 @@ enum
 	PROP_SHOW_TOOLBAR,
 	PROP_TOOLBAR_STYLE,
 	PROP_TOOLBAR_ORIENTATION,
-	PROP_VIEW_MODE
+	PROP_VIEW_MODE,
+	PROP_SHOW_PANEL,
+	PROP_LAST_PANEL_PAGE,
+	PROP_SHOW_AUTOCONNECT_ERRORS
 };
 
 
@@ -125,6 +128,15 @@ static void gigolo_settings_set_property(GObject *object, guint prop_id, const G
 	case PROP_AUTOCONNECT_INTERVAL:
 		priv->autoconnect_interval = g_value_get_int(value);
 		break;
+	case PROP_SHOW_PANEL:
+		priv->show_panel = g_value_get_boolean(value);
+		break;
+	case PROP_LAST_PANEL_PAGE:
+		priv->last_panel_page = g_value_get_uint(value);
+		break;
+	case PROP_SHOW_AUTOCONNECT_ERRORS:
+		priv->show_autoconnect_errors = g_value_get_boolean(value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -167,6 +179,15 @@ static void gigolo_settings_get_property(GObject *object, guint prop_id, GValue
 			g_object_set(object, "autoconnect-interval", DEFAULT_AUTOCONNECT_INTERVAL, NULL);
 		g_value_set_int(value, priv->autoconnect_interval);
 		break;
+	case PROP_SHOW_PANEL:
+		g_value_set_boolean(value, priv->show_panel);
+		break;
+	case PROP_LAST_PANEL_PAGE:
+		g_value_set_uint(value, priv->last_panel_page);
+		break;
+	case PROP_SHOW_AUTOCONNECT_ERRORS:
+		g_value_set_boolean(value, priv->show_autoconnect_errors);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -255,6 +276,30 @@ static void gigolo_settings_class_init(GigoloSettingsClass *klass)
 									"Autoconnect interval",
 									0, G_MAXINT, 0,
 									G_PARAM_READWRITE));
+	g_object_class_install_property(gobject_class,
+									PROP_SHOW_PANEL,
+									g_param_spec_boolean(
+									"show-panel",
+									"show-panel",
+									"Whether to show the side panel",
+									TRUE,
+									G_PARAM_READWRITE));
+	g_object_class_install_property(gobject_class,
+									PROP_LAST_PANEL_PAGE,
+									g_param_spec_uint(
+									"last-panel-page",
+									"last-panel-page",
+									"Last displayed panel page",
+									0, G_MAXUINT, 0,
+									G_PARAM_READWRITE));
+	g_object_class_install_property(gobject_class,
+									PROP_SHOW_AUTOCONNECT_ERRORS,
+									g_param_spec_boolean(
+									"show-autoconnect-errors",
+									"show-autoconnect-errors",
+									"Whether to show error messages when auto-connecting bookmarks fails",
+									TRUE,
+									G_PARAM_READWRITE));
 }
 
 
@@ -364,8 +409,6 @@ static void write_settings_config(GigoloSettings *settings)
 
 	k = g_key_file_new();
 
-	if (priv->vm_impl != NULL)
-		g_key_file_set_string(k, SECTION_GENERAL, "vm_impl", priv->vm_impl);
 	if (priv->file_manager != NULL)
 		g_key_file_set_string(k, SECTION_GENERAL, "file_manager", priv->file_manager);
 	g_key_file_set_integer(k, SECTION_GENERAL, "autoconnect_interval", priv->autoconnect_interval);
@@ -379,6 +422,9 @@ static void write_settings_config(GigoloSettings *settings)
 	g_key_file_set_integer(k, SECTION_UI, "toolbar_style", priv->toolbar_style);
 	g_key_file_set_integer(k, SECTION_UI, "toolbar_orientation", priv->toolbar_orientation);
 	g_key_file_set_integer(k, SECTION_UI, "view_mode", priv->view_mode);
+	g_key_file_set_boolean(k, SECTION_UI, "show_panel", priv->show_panel);
+	g_key_file_set_integer(k, SECTION_UI, "last_panel_page", priv->last_panel_page);
+	g_key_file_set_boolean(k, SECTION_UI, "show_autoconnect_errors", priv->show_autoconnect_errors);
 
 	write_data(k, priv->config_filename);
 
@@ -408,10 +454,12 @@ static void write_settings_bookmarks(GigoloSettings *settings)
 		{
 			name = gigolo_bookmark_get_name(bm);
 			set_setting_string(k, name, "host", gigolo_bookmark_get_host(bm));
+			set_setting_string(k, name, "folder", gigolo_bookmark_get_folder(bm));
 			set_setting_string(k, name, "user", gigolo_bookmark_get_user(bm));
 			set_setting_string(k, name, "scheme", gigolo_bookmark_get_scheme(bm));
 			set_setting_string(k, name, "share", gigolo_bookmark_get_share(bm));
 			set_setting_string(k, name, "domain", gigolo_bookmark_get_domain(bm));
+			set_setting_string(k, name, "path", gigolo_bookmark_get_path(bm));
 			set_setting_int(k, name, "port", gigolo_bookmark_get_port(bm));
 			set_setting_int(k, name, "autoconnect", gigolo_bookmark_get_autoconnect(bm));
 		}
@@ -441,7 +489,6 @@ static void gigolo_settings_finalize(GObject* object)
 	gigolo_settings_write(GIGOLO_SETTINGS(object),
 		GIGOLO_SETTINGS_PREFERENCES | GIGOLO_SETTINGS_BOOKMARKS);
 
-	g_free(priv->vm_impl);
 	g_free(priv->geometry);
 
 	g_ptr_array_foreach(priv->bookmarks, (GFunc) g_object_unref, NULL);
@@ -469,7 +516,6 @@ static void load_settings_read_config(GigoloSettingsPrivate *priv)
 		error = NULL;
 	}
 
-	priv->vm_impl = get_setting_string(k, SECTION_GENERAL, "vm_impl", DEFAULT_VM_IMPL);
 	priv->file_manager = get_setting_string(k, SECTION_GENERAL, "file_manager", "gvfs-open");
 	priv->autoconnect_interval = get_setting_int(k, SECTION_GENERAL, "autoconnect_interval",
 		DEFAULT_AUTOCONNECT_INTERVAL);
@@ -477,6 +523,9 @@ static void load_settings_read_config(GigoloSettingsPrivate *priv)
 	priv->save_geometry = get_setting_boolean(k, SECTION_UI, "save_geometry", TRUE);
 	priv->show_in_systray = get_setting_boolean(k, SECTION_UI, "show_in_systray", TRUE);
 	priv->start_in_systray = get_setting_boolean(k, SECTION_UI, "start_in_systray", FALSE);
+	priv->show_panel = get_setting_boolean(k, SECTION_UI, "show_panel", FALSE);
+	priv->last_panel_page = get_setting_int(k, SECTION_UI, "last_panel_page", 0);
+	priv->show_autoconnect_errors = get_setting_boolean(k, SECTION_UI, "show_autoconnect_errors", TRUE);
 	priv->show_toolbar = get_setting_boolean(k, SECTION_UI, "show_toolbar", TRUE);
 	priv->toolbar_style = get_setting_int(k, SECTION_UI, "toolbar_style", -1);
 	priv->toolbar_orientation = get_setting_int(k, SECTION_UI, "toolbar_orientation", 0);
@@ -512,7 +561,7 @@ static void load_settings_read_bookmarks(GigoloSettingsPrivate *priv)
 	GError *error = NULL;
 	gsize len, i;
 	gchar **groups;
-	gchar *scheme, *host, *user, *domain, *share;
+	gchar *scheme, *host, *user, *domain, *share, *folder, *path;
 	gint port;
 	gboolean autoconnect;
 	GigoloBookmark *bm;
@@ -531,6 +580,8 @@ static void load_settings_read_bookmarks(GigoloSettingsPrivate *priv)
 	{
 		scheme = get_setting_string(k, groups[i], "scheme", "");
 		host = get_setting_string(k, groups[i], "host", "");
+		folder = get_setting_string(k, groups[i], "folder", "");
+		path = get_setting_string(k, groups[i], "path", "");
 		user = get_setting_string(k, groups[i], "user", "");
 		domain = get_setting_string(k, groups[i], "domain", "");
 		share = get_setting_string(k, groups[i], "share", "");
@@ -542,10 +593,14 @@ static void load_settings_read_bookmarks(GigoloSettingsPrivate *priv)
 		gigolo_bookmark_set_scheme(bm, scheme);
 		if (NZV(host))
 			gigolo_bookmark_set_host(bm, host);
+		if (NZV(folder))
+			gigolo_bookmark_set_folder(bm, folder);
 		if (NZV(user))
 			gigolo_bookmark_set_user(bm, user);
 		if (NZV(domain))
 			gigolo_bookmark_set_domain(bm, domain);
+		if (NZV(path))
+			gigolo_bookmark_set_path(bm, path);
 		if (NZV(share))
 			gigolo_bookmark_set_share(bm, share);
 		gigolo_bookmark_set_port(bm, port);
@@ -555,6 +610,8 @@ static void load_settings_read_bookmarks(GigoloSettingsPrivate *priv)
 
 		g_free(scheme);
 		g_free(host);
+		g_free(folder);
+		g_free(path);
 		g_free(user);
 		g_free(domain);
 		g_free(share);
@@ -613,30 +670,6 @@ GigoloSettings *gigolo_settings_new(void)
 }
 
 
-const gchar *gigolo_settings_get_vm_impl(GigoloSettings *settings)
-{
-	g_return_val_if_fail(settings != NULL, NULL);
-
-	return GIGOLO_SETTINGS_GET_PRIVATE(settings)->vm_impl;
-}
-
-
-void gigolo_settings_set_vm_impl(GigoloSettings *settings, const gchar *impl)
-{
-	GigoloSettingsPrivate *priv;
-
-	g_return_if_fail(settings != NULL);
-
-	priv = GIGOLO_SETTINGS_GET_PRIVATE(settings);
-
-	if (impl == NULL)
-		impl = "hal";
-
-	g_free(priv->vm_impl);
-	priv->vm_impl = g_strdup(impl);
-}
-
-
 const gint *gigolo_settings_get_geometry(GigoloSettings *settings)
 {
 	g_return_val_if_fail(settings != NULL, NULL);
@@ -723,3 +756,31 @@ gboolean gigolo_settings_has_file_manager(GigoloSettings *settings)
 
 	return NZV(priv->file_manager);
 }
+
+
+GigoloBookmark *gigolo_settings_get_bookmark_by_uri(GigoloSettings *settings, const gchar *uri)
+{
+	GigoloBookmarkList *bml;
+	GigoloBookmark *bm = NULL;
+	gboolean found = FALSE;
+	gchar *tmp_uri;
+	guint i;
+
+	g_return_val_if_fail(settings != NULL, FALSE);
+	g_return_val_if_fail(uri != NULL, FALSE);
+
+	bml = gigolo_settings_get_bookmarks(settings);
+
+	for (i = 0; i < bml->len && ! found; i++)
+	{
+		bm = g_ptr_array_index(bml, i);
+		tmp_uri = gigolo_bookmark_get_uri_escaped(bm);
+		if (gigolo_str_equal(uri, tmp_uri))
+			found = TRUE;
+
+		g_free(tmp_uri);
+	}
+	return (found) ? bm : NULL;
+}
+
+
